pub enum Status {
Show 19 variants
NonAnonymousRoom,
AffiliationChange,
ConfigShowsUnavailableMembers,
ConfigHidesUnavailableMembers,
ConfigNonPrivacyRelated,
SelfPresence,
ConfigRoomLoggingEnabled,
ConfigRoomLoggingDisabled,
ConfigRoomNonAnonymous,
ConfigRoomSemiAnonymous,
RoomHasBeenCreated,
AssignedNick,
Banned,
NewNick,
Kicked,
RemovalFromRoom,
ConfigMembersOnly,
ServiceShutdown,
ServiceErrorKick,
}Expand description
Lists all of the possible status codes used in MUC presences.
Variants
NonAnonymousRoom
100: Inform user that any occupant is allowed to see the user’s full JID
AffiliationChange
101: Inform user that his or her affiliation changed while not in the room
102: Inform occupants that room now shows unavailable members
103: Inform occupants that room now does not show unavailable members
ConfigNonPrivacyRelated
104: Inform occupants that a non-privacy-related room configuration change has occurred
SelfPresence
110: Inform user that presence refers to itself
ConfigRoomLoggingEnabled
170: Inform occupants that room logging is now enabled
ConfigRoomLoggingDisabled
171: Inform occupants that room logging is now disabled
ConfigRoomNonAnonymous
172: Inform occupants that the room is now non-anonymous
ConfigRoomSemiAnonymous
173: Inform occupants that the room is now semi-anonymous
RoomHasBeenCreated
201: Inform user that a new room has been created
AssignedNick
210: Inform user that service has assigned or modified occupant’s roomnick
Banned
301: Inform user that they have been banned from the room
NewNick
303: Inform all occupants of new room nickname
Kicked
307: Inform user that they have been kicked from the room
RemovalFromRoom
321: Inform user that they are being removed from the room because of an affiliation change
ConfigMembersOnly
322: Inform user that they are being removed from the room because the room has been changed to members-only and the user is not a member
ServiceShutdown
332: Inform user that they are being removed from the room because the MUC service is being shut down
ServiceErrorKick
333: Inform user that they are being removed from the room for technical reasons